@@ -99,7 +99,7 @@ mod tests {
             "（路透社）-预计全年净亏损约1.3亿港元*预期因出售汽车" => "（路透社）- 预计全年净亏损约 1.3 亿港元*预期因出售汽车",
             "（路透社）-预计全年净亏损约1.3亿\n\n港元*预期因出售汽车" => "（路透社）- 预计全年净亏损约 1.3 亿\n\n港元*预期因出售汽车",
             "Cell或RefCell类型使用某种形式的*内部" => "Cell 或 RefCell 类型使用某种形式的*内部",
-            "Cell或RefCell类型使用某种形式的*内部可变性*" => "Cell 或 RefCell 类型使用某种形式的*内部可变性*",
+            "Cell或RefCell类型使用某种形式的*内部可变性*" => "Cell 或 RefCell 类型使用某种形式的*内部可变性*"
         ];
 
         assert_cases(cases);
@@ -176,6 +176,7 @@ mod tests {
             "以达到快速、 跨平台 、 低资源占用的目的 。 很多著名且受欢迎的软件，例如 Firefox 、 Dropbox 和 Cloudflare 都在使用" => "以达到快速、跨平台、低资源占用的目的。很多著名且受欢迎的软件，例如 Firefox、Dropbox 和 Cloudflare 都在使用",
             "注意： 引进给变量， 转换为机器代码。 这意味着任何变量、 常量； 命名的概念都会被删除" => "注意：引进给变量，转换为机器代码。这意味着任何变量、常量；命名的概念都会被删除",
             "注意 ： 引进给变量 ， 转换为机器代码 。 这意味着任何变量 、 常量 ； 命名的概念都会被删除" => "注意：引进给变量，转换为机器代码。这意味着任何变量、常量；命名的概念都会被删除",
+            "测试测试， `code` 测试测试" => "测试测试，`code` 测试测试"
         ];
 
         assert_cases(cases);
